/**
 * <copyright>
 * </copyright>
 *
 * $Id: COBOLUsageValues.java,v 1.2 2004/10/21 21:57:45 akkina Exp $
 */
package com.ibm.etools.cobol;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;

import org.eclipse.emf.common.util.AbstractEnumerator;

/**
 * <!-- begin-user-doc -->
 * A representation of the literals of the enumeration '<em><b>Usage Values</b></em>',
 * and utility methods for working with them.
 * <!-- end-user-doc -->
 * <!-- begin-model-doc -->
 * The FUNCTION-POINTER phrase defines an item as a function-pointer data item.
 * A function-pointer data item can contain the address of a procedure entry point.
 * 
 * A function-pointer is a 4-byte elementary item. Function-pointers have the same
 * capabilities as procedure-pointers, but are 4 bytes in length instead of 8 bytes.
 * Function-pointers are thus more easily interoperable with C function pointers.
 * 
 * A function-pointer can contain the address of:
 *   -  the primary entry point of a COBOL program, defined by the PROGRAM-ID
 *      paragraph of the outermost program,
 *   -  an alternate entry point of a COBOL program, defined by a COBOL ENTRY
 *      statement,
 *   -  an entry point in a non-COBOL program,
 *   or can contain NULL.
 * 
 * A VALUE clause for a function-pointer data item can contain only NULL or
 * NULLS.
 * 
 * A function-pointer can be used in the same contexts as a procedure-pointer
 * 
 * <!-- end-model-doc -->
 * @see com.ibm.etools.cobol.COBOLPackage#getCOBOLUsageValues()
 * @model
 * @generated
 */
public final class COBOLUsageValues extends AbstractEnumerator {
	/**
	 * The '<em><b>Binary</b></em>' literal value.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #BINARY_LITERAL
	 * @model name="binary"
	 * @generated
	 * @ordered
	 */
	public static final int BINARY = 0;

	/**
	 * The '<em><b>Dbcs</b></em>' literal value.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #DBCS_LITERAL
	 * @model name="dbcs"
	 * @generated
	 * @ordered
	 */
	public static final int DBCS = 1;

	/**
	 * The '<em><b>Double</b></em>' literal value.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #DOUBLE_LITERAL
	 * @model name="double"
	 * @generated
	 * @ordered
	 */
	public static final int DOUBLE = 2;

	/**
	 * The '<em><b>Display</b></em>' literal value.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #DISPLAY_LITERAL
	 * @model name="display"
	 * @generated
	 * @ordered
	 */
	public static final int DISPLAY = 3;

	/**
	 * The '<em><b>Float</b></em>' literal value.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #FLOAT_LITERAL
	 * @model name="float"
	 * @generated
	 * @ordered
	 */
	public static final int FLOAT = 4;

	/**
	 * The '<em><b>Index</b></em>' literal value.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #INDEX_LITERAL
	 * @model name="index"
	 * @generated
	 * @ordered
	 */
	public static final int INDEX = 5;

	/**
	 * The '<em><b>National</b></em>' literal value.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #NATIONAL_LITERAL
	 * @model name="national"
	 * @generated
	 * @ordered
	 */
	public static final int NATIONAL = 6;

	/**
	 * The '<em><b>Object Reference</b></em>' literal value.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #OBJECT_REFERENCE_LITERAL
	 * @model name="objectReference"
	 * @generated
	 * @ordered
	 */
	public static final int OBJECT_REFERENCE = 7;

	/**
	 * The '<em><b>Packed Decimal</b></em>' literal value.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #PACKED_DECIMAL_LITERAL
	 * @model name="packedDecimal"
	 * @generated
	 * @ordered
	 */
	public static final int PACKED_DECIMAL = 8;

	/**
	 * The '<em><b>Pointer</b></em>' literal value.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #POINTER_LITERAL
	 * @model name="pointer"
	 * @generated
	 * @ordered
	 */
	public static final int POINTER = 9;

	/**
	 * The '<em><b>Procedure Pointer</b></em>' literal value.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #PROCEDURE_POINTER_LITERAL
	 * @model name="procedurePointer"
	 * @generated
	 * @ordered
	 */
	public static final int PROCEDURE_POINTER = 10;

	/**
	 * The '<em><b>Function Pointer</b></em>' literal value.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #FUNCTION_POINTER_LITERAL
	 * @model name="functionPointer"
	 * @generated
	 * @ordered
	 */
	public static final int FUNCTION_POINTER = 11;

	/**
	 * The '<em><b>Binary</b></em>' literal object.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * <!-- begin-model-doc -->
	 * Specified in the usage clause as BINARY, COMP, COMPUTATIONAL, COMP-4, 
	 * COMPUTATIONAL-4, COMP-5, or COMPUTATIONAL-5.
	 * Note that in COBOL, COMP-5/COMPUTATIONAL-5 is different from the other formats listed above.  COMP-5 is used to represent native binary data.  This essentially means that you can use up the full memory allocation, ignoring the maximum specified by the picture string.
	 * example1:
	 * 05 Foo PIC 9999 USAGE COMP
	 * In binary format, at least 14 bits of memory are needed to represent the decimal numbers 0 through 9999.  Since machines work in bytes, 2 bytes of memory would be reserved for this element.  In fact, 2 bytes are enough to represent all decimal numbers from 0 to 65535.  But, because we specified usage COMP, you cannot store any number larger than 9999 in this element.
	 * example 2:
	 * 05 Foo PIC 9999 USAGE COMP-5
	 * In this field you can store any number from 0 to 65535.  Note that in our model both COMP and COMP-5 are represented by the same usage format (binary).  The following shows the number of memory bytes used versus the number of decimal digits (9's) in the picture string
	 * 
	 * 1 through 4 digits --> 2 bytes (halfword)
	 * 5 through 9 digits --> 4 bytes (fullword)
	 * 10 through 18 digits --> 8 bytes (doubleword)
	 * Note that the maximum length of a computational item is 18 
	 * decimal digits.
	 * 
	 * 
	 * <!-- end-model-doc -->
	 * @see #BINARY
	 * @generated
	 * @ordered
	 */
	public static final COBOLUsageValues BINARY_LITERAL = new COBOLUsageValues(BINARY, "binary");

	/**
	 * The '<em><b>Dbcs</b></em>' literal object.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * <!-- begin-model-doc -->
	 *  The DISPLAY-1 phrase defines an item as DBCS. 
	 * 
	 * <!-- end-model-doc -->
	 * @see #DBCS
	 * @generated
	 * @ordered
	 */
	public static final COBOLUsageValues DBCS_LITERAL = new COBOLUsageValues(DBCS, "dbcs");

	/**
	 * The '<em><b>Double</b></em>' literal object.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * <!-- begin-model-doc -->
	 * COMPUTATIONAL-2 or COMP-2 (Long Floating-Point)
	 *  Specified for internal floating-point items (double precision). 
	 *  COMP-2 items are 8 bytes long. 
	 * 
	 * <!-- end-model-doc -->
	 * @see #DOUBLE
	 * @generated
	 * @ordered
	 */
	public static final COBOLUsageValues DOUBLE_LITERAL = new COBOLUsageValues(DOUBLE, "double");

	/**
	 * The '<em><b>Display</b></em>' literal object.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * <!-- begin-model-doc -->
	 * The data item is stored in character form, 1 character for each 8-bit byte. This corresponds to the format used for printed output. DISPLAY can be explicit or implicit. 
	 * USAGE IS DISPLAY is valid for the following types of items: 
	 * Alphabetic 
	 * Alphanumeric 
	 * Alphanumeric-edited 
	 * Numeric-edited 
	 * External floating-point 
	 * External decimal (numeric) 
	 * 
	 * <!-- end-model-doc -->
	 * @see #DISPLAY
	 * @generated
	 * @ordered
	 */
	public static final COBOLUsageValues DISPLAY_LITERAL = new COBOLUsageValues(DISPLAY, "display");

	/**
	 * The '<em><b>Float</b></em>' literal object.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * <!-- begin-model-doc -->
	 * COMPUTATIONAL-1 or COMP-1 (floating-point) 
	 *  Specified for internal floating-point items (single precision). 
	 *  COMP-1 items are 4 bytes long. 
	 * 
	 * <!-- end-model-doc -->
	 * @see #FLOAT
	 * @generated
	 * @ordered
	 */
	public static final COBOLUsageValues FLOAT_LITERAL = new COBOLUsageValues(FLOAT, "float");

	/**
	 * The '<em><b>Index</b></em>' literal object.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * <!-- begin-model-doc -->
	 * A data item defined with the INDEX phrase is an index data item. 
	 * An index data item is a 4-byte elementary item (not necessarily connected with any table) that can be used to save index-name values for future reference. Through a SET statement, an index data item can be assigned an index-name value; such a value corresponds to the occurrence number in a table. 
	 * Direct references to an index data item can be made only in a SEARCH statement, a SET statement, a relation condition, the USING phrase of the Procedure Division header, or the USING phrase of the CALL statement. 
	 * 
	 *  An index data item can be referred to directly in the USING phrase of an 
	 *  ENTRY statement. 
	 * An index data item can be part of a group item referred to in a MOVE statement or an input/output statement. 
	 * An index data item saves values that represent table occurrences, yet is not necessarily defined as part of any table. Thus, when it is referred to directly in a SEARCH or SET statement, or indirectly in a MOVE or input/output statement, there is no conversion of values when the statement is executed. 
	 * The USAGE IS INDEX clause can be written at any level. If a group item is described with the USAGE IS INDEX clause, the elementary items within the group are index data items; the group itself is not an index data item, and the group name cannot be used in SEARCH and SET statements or in relation conditions. The USAGE clause of an elementary item cannot contradict the USAGE clause of a group to which the item belongs. 
	 * An index data item cannot be a conditional variable. 
	 * 
	 *  The DATE FORMAT, JUSTIFIED, PICTURE, BLANK WHEN ZERO, SYNCHRONIZED, or VALUE clauses cannot be used to describe group or elementary items described with the USAGE IS INDEX clause. 
	 * 
	 *  SYNCHRONIZED can be used with USAGE IS INDEX to obtain efficient use of 
	 *  the index data item. 
	 * 
	 * <!-- end-model-doc -->
	 * @see #INDEX
	 * @generated
	 * @ordered
	 */
	public static final COBOLUsageValues INDEX_LITERAL = new COBOLUsageValues(INDEX, "index");

	/**
	 * The '<em><b>National</b></em>' literal object.
	 * <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of '<em><b>National</b></em>' literal object isn't clear,
	 * there really should be more of a description here...
	 * </p>
	 * <!-- end-user-doc -->
	 * @see #NATIONAL
	 * @generated
	 * @ordered
	 */
	public static final COBOLUsageValues NATIONAL_LITERAL = new COBOLUsageValues(NATIONAL, "national");

	/**
	 * The '<em><b>Object Reference</b></em>' literal object.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * <!-- begin-model-doc -->
	 *  A data item defined with the OBJECT REFERENCE phrase is an object 
	 *  reference. 
	 * 
	 *  The USAGE IS OBJECT REFERENCE clause can be used at any level except level 
	 *  66 or 88. If a group item is described with the USAGE IS OBJECT REFERENCE 
	 *  clause, the elementary items within the group are object-reference data 
	 *  items. The group itself is not an object reference. The USAGE clause of 
	 *  an elementary item cannot contradict the USAGE clause of a group that 
	 *  contains the item. 
	 * 
	 *  Object reference data items: 
	 *  Are ignored in CORRESPONDING operations 
	 *  Are unaffected by INITIALIZE statements 
	 *  Can be the subject or object of a REDEFINES clause 
	 *  Cannot be a conditional variable 
	 *  Can be written to a file (but upon subsequent reading of the record 
	 * 	 the content of the object reference is undefined) 
	 * 
	 *  A VALUE clause for an object-reference data item can contain only NULL or 
	 *  NULLS. 
	 * 
	 *  You can use the SYNCHRONIZED clause with USAGE IS OBJECT REFERENCE to 
	 *  obtain efficient alignment of the object-reference data item. 
	 * 
	 *  The DATE FORMAT, JUSTIFIED, PICTURE, and BLANK WHEN ZERO clauses cannot be 
	 *  used to describe group or elementary items defined with the USAGE IS 
	 *  OBJECT REFERENCE clause. 
	 * 
	 * <!-- end-model-doc -->
	 * @see #OBJECT_REFERENCE
	 * @generated
	 * @ordered
	 */
	public static final COBOLUsageValues OBJECT_REFERENCE_LITERAL = new COBOLUsageValues(OBJECT_REFERENCE, "objectReference");

	/**
	 * The '<em><b>Packed Decimal</b></em>' literal object.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * <!-- begin-model-doc -->
	 * This format uses 2 digits for each character position, except for the trailing character position, which is occupied by the low-order digit and the sign.
	 * 
	 * Specified for internal decimal items. Such an item appears in storage in packed decimal format. There are 2 digits for each character position, except for the trailing character position, which is occupied by the low-order digit and the sign. Such an item can contain any of the digits 0 through 9, plus a sign, representing a value not exceeding 18 decimal digits. 
	 * COMPUTATIONAL-3 or COMP-3 (internal decimal) 
	 *  This is the equivalent of PACKED-DECIMAL. 
	 * 
	 * <!-- end-model-doc -->
	 * @see #PACKED_DECIMAL
	 * @generated
	 * @ordered
	 */
	public static final COBOLUsageValues PACKED_DECIMAL_LITERAL = new COBOLUsageValues(PACKED_DECIMAL, "packedDecimal");

	/**
	 * The '<em><b>Pointer</b></em>' literal object.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * <!-- begin-model-doc -->
	 * A data item defined with USAGE IS POINTER is a pointer data item. A 
	 *  pointer data item is a 4-byte elementary item, 
	 *  You can use pointer data items to accomplish limited base addressing. 
	 *  Pointer data items can be compared for equality or moved to other pointer 
	 *  items. 
	 *  A pointer data item can only be used: 
	 *  In a SET statement (format 5 only) 
	 *  In a relation condition 
	 *  In the USING phrase of a CALL statement, an ENTRY statement, or the 
	 *  Procedure Division header. 
	 * 
	 *  The USAGE IS POINTER clause can be written at any level except level 88. 
	 *  If a group item is described with the USAGE IS POINTER clause, the 
	 *  elementary items within the group are pointer data items; the group itself 
	 *  is not a pointer data item and cannot be used in the syntax where a 
	 *  pointer data item is allowed. The USAGE clause of an elementary item 
	 *  cannot contradict the USAGE clause of a group to which the item belongs. 
	 *  Pointer data items can be part of a group that is referred to in a MOVE 
	 *  statement or an input/output statement. However, if a pointer data item 
	 *  is part of a group, there is no conversion of values when the statement is 
	 *  executed. 
	 *  A pointer data item can be the subject or object of a REDEFINES clause. 
	 *  SYNCHRONIZED can be used with USAGE IS POINTER to obtain efficient use of 
	 *  the pointer data item. 
	 *  A VALUE clause for a pointer data item can contain only NULL or NULLS. 
	 *  A pointer data item cannot be a conditional variable. 
	 *  A pointer data item does not belong to any class or category. 
	 *  The DATE FORMAT, JUSTIFIED, PICTURE, and BLANK WHEN ZERO clauses cannot be 
	 *  used to describe group or elementary items defined with the USAGE IS 
	 *  POINTER clause. 
	 *  Pointer data items are ignored in CORRESPONDING operations. 
	 *  A pointer data item can be written to a data set, but, upon subsequent 
	 *  reading of the record containing the pointer, the address contained can no 
	 *  longer represent a valid pointer. 
	 *  Note: USAGE IS POINTER is implicitly specified for the ADDRESS OF special 
	 *  register. For more information, see the IBM COBOL Programming Guide for 
	 *  your platform. 
	 * 
	 * <!-- end-model-doc -->
	 * @see #POINTER
	 * @generated
	 * @ordered
	 */
	public static final COBOLUsageValues POINTER_LITERAL = new COBOLUsageValues(POINTER, "pointer");

	/**
	 * The '<em><b>Procedure Pointer</b></em>' literal object.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * <!-- begin-model-doc -->
	 * A procedure-pointer data item can contain the address of a procedure entry 
	 *  point. Procedure-pointer data items can be compared for equality or moved 
	 *  to other procedure-pointer data items. 
	 * 
	 *  The entry point address and code address are contained in the first word. 
	 *  The second word is binary zero. 
	 * 
	 *  The USAGE IS PROCEDURE-POINTER clause can be written at any level except 
	 *  level 88. 
	 * 
	 *  SYNCHRONIZED can be used with USAGE IS PROCEDURE-POINTER to obtain 
	 *  efficient alignment of the procedure-pointer data item. 
	 * 
	 *  The GLOBAL, EXTERNAL, and OCCURS clause can be used with USAGE IS 
	 *  PROCEDURE-POINTER. 
	 * 
	 *  A VALUE clause for a procedure-pointer data item can contain only NULL or 
	 *  NULLS. 
	 * 
	 *  The DATE FORMAT, JUSTIFIED, PICTURE, and BLANK WHEN ZERO clauses cannot be 
	 *  used to describe group or elementary items defined with the USAGE IS 
	 *  PROCEDURE-POINTER clause. 
	 * 
	 *  A procedure-pointer data item cannot be a conditional variable. 
	 * 
	 *  A procedure-pointer data item does not belong to any class or category. 
	 * 
	 *  Procedure-pointer data items are ignored in CORRESPONDING operations. 
	 * 
	 * <!-- end-model-doc -->
	 * @see #PROCEDURE_POINTER
	 * @generated
	 * @ordered
	 */
	public static final COBOLUsageValues PROCEDURE_POINTER_LITERAL = new COBOLUsageValues(PROCEDURE_POINTER, "procedurePointer");

	/**
	 * The '<em><b>Function Pointer</b></em>' literal object.
	 * <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of '<em><b>Function Pointer</b></em>' literal object isn't clear,
	 * there really should be more of a description here...
	 * </p>
	 * <!-- end-user-doc -->
	 * @see #FUNCTION_POINTER
	 * @generated
	 * @ordered
	 */
	public static final COBOLUsageValues FUNCTION_POINTER_LITERAL = new COBOLUsageValues(FUNCTION_POINTER, "functionPointer");

	/**
	 * An array of all the '<em><b>Usage Values</b></em>' enumerators.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	private static final COBOLUsageValues[] VALUES_ARRAY =
		new COBOLUsageValues[] {
			BINARY_LITERAL,
			DBCS_LITERAL,
			DOUBLE_LITERAL,
			DISPLAY_LITERAL,
			FLOAT_LITERAL,
			INDEX_LITERAL,
			NATIONAL_LITERAL,
			OBJECT_REFERENCE_LITERAL,
			PACKED_DECIMAL_LITERAL,
			POINTER_LITERAL,
			PROCEDURE_POINTER_LITERAL,
			FUNCTION_POINTER_LITERAL,
		};

	/**
	 * A public read-only list of all the '<em><b>Usage Values</b></em>' enumerators.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public static final List VALUES = Collections.unmodifiableList(Arrays.asList(VALUES_ARRAY));

	/**
	 * Returns the '<em><b>Usage Values</b></em>' literal with the specified name.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public static COBOLUsageValues get(String name) {
		for (int i = 0; i < VALUES_ARRAY.length; ++i) {
			COBOLUsageValues result = VALUES_ARRAY[i];
			if (result.toString().equals(name)) {
				return result;
			}
		}
		return null;
	}

	/**
	 * Returns the '<em><b>Usage Values</b></em>' literal with the specified value.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public static COBOLUsageValues get(int value) {
		switch (value) {
			case BINARY: return BINARY_LITERAL;
			case DBCS: return DBCS_LITERAL;
			case DOUBLE: return DOUBLE_LITERAL;
			case DISPLAY: return DISPLAY_LITERAL;
			case FLOAT: return FLOAT_LITERAL;
			case INDEX: return INDEX_LITERAL;
			case NATIONAL: return NATIONAL_LITERAL;
			case OBJECT_REFERENCE: return OBJECT_REFERENCE_LITERAL;
			case PACKED_DECIMAL: return PACKED_DECIMAL_LITERAL;
			case POINTER: return POINTER_LITERAL;
			case PROCEDURE_POINTER: return PROCEDURE_POINTER_LITERAL;
			case FUNCTION_POINTER: return FUNCTION_POINTER_LITERAL;
		}
		return null;	
	}

	/**
	 * Only this class can construct instances.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	private COBOLUsageValues(int value, String name) {
		super(value, name);
	}

} //COBOLUsageValues
