/*
 * Created on Aug 17, 2004
 *
 */
package com.ibm.etools.cobol.importer;

import java.util.Vector;

/**
 * @author makkina
 * 
 * Consists of all the various locales and ascii code pages that are supported
 * on the Windows COBOL compiler.
 * TODO: Make this a singleton class
 */
public class COBOLLocaleRelatedConstants {

	public static final String copyright = "(c) Copyright IBM Corporation 2004.";
	public String PLUGIN_ID="com.ibm.etools.cobol";
	private Vector localeNameList;
	private Vector errorMessagesLanguagesList;
	
	private final String[] localNames = { "en_US", /*Default*/
			               "ar_AA", "be_BY", "bg_BG", "ca_ES", "cs_CZ", "da_DK", "de_CH", "de_DE", 
			               "el_GR", "en_AU", "en_BE", "en_GB", "en_JP", "en_US", "en_ZA", "es_ES", 
						   "fi_FI", "fr_BE", "fr_CA", "fr_CH", "fr_FR", "hr_HR", "hu_HU", "is_IS", 
						   "it_CH", "it_IT", "iw_IL", "ja_JP", "ko_KR", "lt_LT", "lv_LV", "mk_MK", 
						   "nl_BE", "nl_NL", "no_NO", "pl_PL", "pt_BR", "pt_PT", "ro_RO", "ru_RU", 
						   "sh_SP", "sk_SK", "sl_SL", "sq_AL", "sv_SE", "th_TH", "tr_TR", "uk_UA", 
						   "zh_CN", "zh_TW"
						   };
	/* 
	 * @author makkina
	 *
	 * The entries are in reverse order of what is documented in the "Supported locales and code pages" table,
	 * so that the default value that is picked will be the last one.
	 */
	private final String[][] asciiCodePages = {
			{"IBM-1252","IBM-850","IBM-437"}, /*Default*/
			{"IBM-1256","IBM-864"},
			{"IBM-1251","IBM-866"},
			{"IBM-1251","IBM-855"},
			{"IBM-1252","IBM-850"},
			{"IBM-1250","IBM-852"},
			{"IBM-1252","IBM-850","IBM-437"},
			{"IBM-1252","IBM-850","IBM-437"},
			{"IBM-1252","IBM-850","IBM-437"},
			{"IBM-1253"},
			{"IBM-1252","IBM-437"},
			{"IBM-1252","IBM-850"},
			{"IBM-1252","IBM-850","IBM-437"},
			{"IBM-1252","IBM-850","IBM-437"},
			{"IBM-1252","IBM-850","IBM-437"},
			{"IBM-1252","IBM-437"},
			{"IBM-1252","IBM-850","IBM-437"},
			{"IBM-1252","IBM-850","IBM-437"},
			{"IBM-1252","IBM-850","IBM-437"},
			{"IBM-1252","IBM-850","IBM-863"},
			{"IBM-1252","IBM-850","IBM-437"},
			{"IBM-1252","IBM-850","IBM-437"},
			{"IBM-1250","IBM-852"},
			{"IBM-1250","IBM-852"},
			{"IBM-1252","IBM-850","IBM-861"},
			{"IBM-1252","IBM-850"},
			{"IBM-437","IBM-850","IBM-1252"},
			{"IBM-1255","IBM-862"},
			{"IBM-943"},
			{"IBM-1363"},
			{"IBM-1257"},
			{"IBM-1257"},
			{"IBM-1251","IBM-855"},
			{"IBM-1252","IBM-850","IBM-437"},
			{"IBM-1252","IBM-850","IBM-437"},
			{"IBM-1252","IBM-850","IBM-437"},
			{"IBM-1250","IBM-852"},
			{"IBM-1252","IBM-850"},
			{"IBM-1252","IBM-850","IBM-860"},
			{"IBM-1250","IBM-850","IBM-852"},
			{"IBM-1251","IBM-866"},
			{"IBM-1250","IBM-852"},
			{"IBM-1250","IBM-852"},
			{"IBM-1250","IBM-852"},
			{"IBM-1252","IBM-850"},
			{"IBM-1252","IBM-850","IBM-437"},
			{"IBM-874"},
			{"IBM-1254","IBM-857"},
			{"IBM-1251","IBM-866"},
			{"IBM-1386"},
			{"IBM-950"}			
	};
	
	private final String[] errorMessagesLanguages = {"EN_US", "JA_JP", "ZH_TW", "ZH_CN", "KO_KR", "IT_IT", "FR_FR", "ES_ES", "DE_DE", "PT_BR"};		
	
	public COBOLLocaleRelatedConstants(){
		localeNameList = new Vector();
		errorMessagesLanguagesList = new Vector();
		for (int i = 0; i < localNames.length; ++i){
			localeNameList.add(localNames[i]);
		}
		for (int i = 0; i < errorMessagesLanguages.length; ++i){
			errorMessagesLanguagesList.add(errorMessagesLanguages[i]);
		}		
	}
	
	public Vector getLocaleNames(){
		return localeNameList;
	}

	public Vector getErrorMessagesLanguage(){
		return errorMessagesLanguagesList;
	}
	
	public Vector getASCIICodePages(String localeName) {		
		Vector v = new Vector();
		int i = localeNameList.indexOf(localeName); 
		if ( i != -1){
			for (int j = 0; j < asciiCodePages[i].length; ++j)
				v.add(asciiCodePages[i][j]);
		}			
		return v;
	}		
}
