package com.ibm.etools.marshall.util;

// ****************************************************************
//
//   IBM Confidential
//   OCO Source Materials
//   <<PART NUMBER - 5724-B75>>
//   (C) Copyright IBM Corp. 2002 - All Rights Reserved.
//   US Government Users Restricted Rights - Use, duplication or disclosure
//   restricted by GSA ADP Schedule Contract with IBM Corp.
//
// ****************************************************************

import java.io.*;
import java.util.*;
import java.text.MessageFormat;

/**
 *   A singleton class implementing mapping from string keys to localized
 *   error messages.
 */

public class MarshallResource implements Serializable
{
	private static final String copyright = "(c) Copyright IBM Corporation 2002.";

	// Message constants
  
	public static final String MARSHRT_FPNUM_OUTOF_RANGE = "MARSHRT_FPNUM_OUTOF_RANGE";
	public static final String MARSHRT_FORMULA_NULL = "MARSHRT_FORMULA_NULL";
	public static final String MARSHRT_PACKDEC_SIGN_NOT_VALID = "MARSHRT_PACKDEC_SIGN_NOT_VALID";
	public static final String MARSHRT_PDNUM_OUTOF_RANGE = "MARSHRT_PDNUM_OUTOF_RANGE";
	public static final String MARSHRT_EXTDEC_SIGN_NOT_VALID = "MARSHRT_EXTDEC_SIGN_NOT_VALID";
	public static final String MARSHRT_EXTDEC_SIGN_FMT_NOT_VALID = "MARSHRT_EXTDEC_SIGN_FMT_NOT_VALID";
	public static final String MARSHRT_FP_16_NOT_SUPPORTED = "MARSHRT_FP_16_NOT_SUPPORTED";
	public static final String MARSHRT_FP_SIZE_NOT_VALID = "MARSHRT_FP_SIZE_NOT_VALID";
	public static final String MARSHRT_INT16NUM_OUTOF_RANGE = "MARSHRT_INT16NUM_OUTOF_RANGE";
	public static final String MARSHRT_INT_SIZE_NOT_VALID = "MARSHRT_INT_SIZE_NOT_VALID";
	public static final String MARSHRT_STR_CODEPAGE_NOT_SUPPORTED = "MARSHRT_STR_CODEPAGE_NOT_SUPPORTED";
	public static final String MARSHRT_STR_LENGTH_NOT_VALID = "MARSHRT_STR_LENGTH_NOT_VALID";
	public static final String MARSHRT_STR_JUSTIFICATION_NOT_VALID = "MARSHRT_STR_JUSTIFICATION_NOT_VALID";
	public static final String MARSHRT_STR_PREFIX_LENGTH_NOT_VALID = "MARSHRT_STR_PREFIX_LENGTH_NOT_VALID";
	public static final String MARSHRT_BIDI_FLAG_NOT_VALID = "MARSHRT_BIDI_FLAG_NOT_VALID";
	public static final String MARSHRT_BIDI_FLAG_STRING_NOT_VALID = "MARSHRT_BIDI_FLAG_STRING_NOT_VALID";
	public static final String MARSHRT_FLOAT_TYPE_NOT_VALID = "MARSHRT_FLOAT_TYPE_NOT_VALID";
	public static final String MARSHRT_TYPEDESC_CLASS_NOT_VALID = "MARSHRT_TYPEDESC_CLASS_NOT_VALID";
	public static final String MARSHRT_SIZE_NOT_SET = "MARSHRT_SIZE_NOT_SET";
	public static final String MARSHRT_OFFSET_NOT_SET = "MARSHRT_OFFSET_NOT_SET";
	public static final String MARSHRT_CODEPAGE_NOT_SET = "MARSHRT_CODEPAGE_NOT_SET";
	public static final String MARSHRT_PLATFORM_INFO_NOT_SET = "MARSHRT_PLATFORM_INFO_NOT_SET";
	public static final String MARSHRT_EXTDEC_SIGN_NOT_SET = "MARSHRT_EXTDEC_SIGN_NOT_SET";
	public static final String MARSHRT_FLOAT_TYPE_NOT_SET = "MARSHRT_FLOAT_TYPE_NOT_SET";
	public static final String MARSHRT_INT_SIGN_CODING_NOT_SET = "MARSHRT_INT_SIGN_CODING_NOT_SET";
	public static final String MARSHRT_INT_SIGN_CODING_NOT_VALID = "MARSHRT_INT_SIGN_CODING_NOT_VALID";
	public static final String MARSHRT_STRIDE_NOT_SET = "MARSHRT_STRIDE_NOT_SET";
	public static final String IWAA0122E = "IWAA0122E";
	public static final String IWAA0123E = "IWAA0123E";
	public static final String IWAA0124E = "IWAA0124E";
	public static final String IWAA0125E = "IWAA0125E";
	public static final String IWAA0126E = "IWAA0126E";
	public static final String IWAA0127E = "IWAA0127E";
	public static final String IWAA0128E = "IWAA0128E";
	public static final String IWAA0129E = "IWAA0129E";


	static private ResourceBundle res_ = null;
	static private MarshallResource global_ = null;
	static private byte resourceLock_[]  = {0};

/**
 * Creates an instance of a MarshallResource initialized to the current locale.
 * @exception MissingResourceException The requested resource string does not exist.
 */

private MarshallResource() throws MissingResourceException
{
   res_ = ResourceBundle.getBundle ("com.ibm.etools.marshall.util.MarshallResourceBundle",
                                    Locale.getDefault());
}
/**
 * Returns a resource string mapping to the specifed resource key.
 * @param key The resource key to retrieve.
 * @exception MissingResourceException The requested resource string does not exist.
 */

public final String getString (String key) throws MissingResourceException
{
   return (res_.getString(key));
}
/**
 * Returns a resource string mapping to the specifed resource key, and replacement
 * arguments.
 * @param key The resource key to retrieve.
 * @param arg The replacement arguments.
 * @exception MissingResourceException The requested resource string does not exist.
 */

public final String getString (String key, Object arg[]) throws MissingResourceException
{
   String basemsgfmt = res_.getString(key);
   MessageFormat msgfmt = new MessageFormat(basemsgfmt);

   return (msgfmt.format(arg));
}
/**
 * Returns a resource string mapping to the specifed resource key, and replacement
 * argument.
 * @param key The resource key to retrieve.
 * @param arg1 The replacement argument.
 * @exception MissingResourceException The requested resource string does not exist.
 */

public final String getString (String key, String arg1) throws MissingResourceException
{
   if (arg1 != null)
   {
      Object msgobj[] = new Object[1];
      msgobj[0] = arg1;
      return (getString(key, msgobj));
   }
   else
      return (getString(key));
}
/**
 * Returns a resource string mapping to the specifed resource key, and replacement
 * arguments.
 * @param key The resource key to retrieve.
 * @param arg1 The first replacement argument.
 * @param arg2 The second replacement argument.
 * @exception MissingResourceException The requested resource string does not exist.
 */

public final String getString(String key, String arg1, String arg2) throws MissingResourceException
{
   if ((arg1 != null) && (arg2 != null))
   {
      Object msgobj[] = new Object[2];
      msgobj[0] = arg1;
      msgobj[1] = arg2;
      return (getString(key, msgobj));
   }
   else
      return (getString(key));
}
/**
 * Returns a resource string mapping to the specifed resource key, and replacement
 * arguments.
 * @param key The resource key to retrieve.
 * @param arg1 The first replacement argument.
 * @param arg2 The second replacement argument.
 * @param arg3 The third replacement argument.
 * @exception MissingResourceException The requested resource string does not exist.
 */

public final String getString(String key, String arg1, String arg2, String arg3) throws
   MissingResourceException
{
   if ((arg1 != null) && (arg2 != null) && (arg3 != null))
   {
      Object msgobj[] = new Object[3];
      msgobj[0] = arg1;
      msgobj[1] = arg2;
      msgobj[2] = arg3;
      return (getString(key, msgobj));
   }
   else
      return (getString(key));
}
/**
 * Returns a resource string mapping to the specifed resource key, and replacement
 * arguments.
 * @param key The resource key to retrieve.
 * @param arg1 The first replacement argument.
 * @param arg2 The second replacement argument.
 * @param arg3 The third replacement argument.
 * @param arg4 The fourth replacement argument.
 * @exception MissingResourceException The requested resource string does not exist.
 */

public final String getString(String key, String arg1, String arg2, String arg3, String arg4) throws
   MissingResourceException
{
   if ((arg1 != null) && (arg2 != null) && (arg3 != null) && (arg4 != null))
   {
      Object msgobj[] = new Object[4];
      msgobj[0] = arg1;
      msgobj[1] = arg2;
      msgobj[2] = arg3;
      msgobj[3] = arg4;
      return (getString(key, msgobj));
   }
   else
      return (getString(key));
}
/**
 * Returns an instance of a MarshallResource initialized to the current locale.
 * @exception MissingResourceException The requested resource string does not exist.
 */

public static MarshallResource instance() throws MissingResourceException
{
   if (global_ == null)
   {
      synchronized (resourceLock_)
      {
         if (global_ == null)
            global_ = new MarshallResource();
      }
   }

   return (global_);
}
}
